@@ -566,9 +566,8 @@ def RenderFeatures(parameter, *args, **kwargs):
         
         return display(jsobj)
     
-    except :
-        
-        return 'error display : please check parameter'
+    except Exception as e:
+        return 'error display :' + str(e)
 
 def RenderCollection(parameter, *args, **kwargs):
     opacity = kwargs.get('opacity', 0.4)
@@ -630,10 +629,11 @@ def RenderCollection(parameter, *args, **kwargs):
         out_iframe = IFrame(url, '100%', '336px')
 
         return out_iframe
+    
+    except Exception as e:
+        return 'error display :' + str(e)
 
-    except :
-        
-        return 'error display : please check parameter'
+    
 
 def RenderRaster(parameter, *args, **kwargs):
     opacity = kwargs.get('opacity', 1)
@@ -688,8 +688,8 @@ def RenderRaster(parameter, *args, **kwargs):
 
         return display(jsobj)
     
-    except :
-        return 'error display : please check parameter'
+    except Exception as e:
+        return 'error display :' + str(e)
 
 def RGBMap(parameter, *args, **kwargs):
     
@@ -702,22 +702,23 @@ def RGBMap(parameter, *args, **kwargs):
         # Open the file:
         raster = rasterio.open(parameter['data'])
 
-
         b1 = raster.read(parameter['band'][0])
         b2 = raster.read(parameter['band'][1])
         b3 = raster.read(parameter['band'][2])
 
         nrg = np.dstack((b1, b2, b3))
 
-        fig, ax = pyplot.subplots(figsize=(12, 12))
-        pyplot.title(title)
-        pyplot.ylabel(ylabel)
-        pyplot.xlabel(xlabel +'\n'+'\n'+ '© Vallaris Maps')
-        
-        return pyplot.show()
+        fig, ax = plt.subplots(figsize = (12, 12))
+        im = ax.imshow(nrg.squeeze())
+        # ep.colorbar(im)
+        ax.set(title= title)
+        ax.set(xlabel= xlabel +'\n'+'\n'+ '© Vallaris Maps')
+        ax.set(ylabel= ylabel)
+
+        return plt.show()
     
-    except :
-        return 'error display : please check parameter'
+    except Exception as e:
+        return 'error display :' + str(e)
 
 def NDVIMap(parameter, *args, **kwargs):
     
@@ -744,10 +745,10 @@ def NDVIMap(parameter, *args, **kwargs):
         ax.set(xlabel= xlabel +'\n'+'\n'+ '© Vallaris Maps')
         ax.set(ylabel= ylabel)
         
-        return pyplot.show()
+        return plt.show()
     
-    except :
-        return 'error display : please check parameter'
+    except Exception as e:
+        return 'error display :' + str(e)
 
 
 def RGBSave(parameter, *args, **kwargs):
@@ -778,8 +779,8 @@ def RGBSave(parameter, *args, **kwargs):
         return 'Succeed : ' + parameter['output']
             
     
-    except :
-        return 'error to save : please check parameter'
+    except Exception as e:
+        return 'error to save :' + str(e)
 
 def NDVISave(parameter, *args, **kwargs):
     nodata = kwargs.get('nodata', -99)
@@ -808,5 +809,5 @@ def NDVISave(parameter, *args, **kwargs):
         return 'Succeed : ' + parameter['output']
             
     
-    except :
-        return 'error to save : please check parameter'
+    except Exception as e:
+        return 'error to save :' + str(e)
